# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_sma.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick_analytics/v1/tick_sma.proto',
  package='systemathics.apis.services.tick_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;systemathics/apis/services/tick_analytics/v1/tick_sma.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xa4\x03\n\x0eTickSmaRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x45\n\x05\x66ield\x18\x03 \x01(\x0e\x32\x36.systemathics.apis.services.tick_analytics.v1.SmaPrice\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12)\n\x06period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08sampling\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nadjustment\x18\x08 \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\t \x03(\t\x12\x0e\n\x06reject\x18\n \x03(\t\"\x7f\n\x0fTickSmaResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12-\n\x07\x61verage\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue*`\n\x08SmaPrice\x12\x19\n\x15SMA_PRICE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSMA_PRICE_TRADE\x10\x01\x12\x11\n\rSMA_PRICE_BID\x10\x02\x12\x11\n\rSMA_PRICE_ASK\x10\x03\x32\x9b\x01\n\x0eTickSmaService\x12\x88\x01\n\x07TickSma\x12<.systemathics.apis.services.tick_analytics.v1.TickSmaRequest\x1a=.systemathics.apis.services.tick_analytics.v1.TickSmaResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])

_SMAPRICE = _descriptor.EnumDescriptor(
  name='SmaPrice',
  full_name='systemathics.apis.services.tick_analytics.v1.SmaPrice',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SMA_PRICE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMA_PRICE_TRADE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMA_PRICE_BID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMA_PRICE_ASK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=861,
  serialized_end=957,
)
_sym_db.RegisterEnumDescriptor(_SMAPRICE)

SmaPrice = enum_type_wrapper.EnumTypeWrapper(_SMAPRICE)
SMA_PRICE_UNSPECIFIED = 0
SMA_PRICE_TRADE = 1
SMA_PRICE_BID = 2
SMA_PRICE_ASK = 3



_TICKSMAREQUEST = _descriptor.Descriptor(
  name='TickSmaRequest',
  full_name='systemathics.apis.services.tick_analytics.v1.TickSmaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaRequest.field', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaRequest.length', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='period', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaRequest.period', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaRequest.offset', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaRequest.sampling', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaRequest.adjustment', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaRequest.accept', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reject', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaRequest.reject', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=730,
)


_TICKSMARESPONSE = _descriptor.Descriptor(
  name='TickSmaResponse',
  full_name='systemathics.apis.services.tick_analytics.v1.TickSmaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaResponse.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaResponse.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average', full_name='systemathics.apis.services.tick_analytics.v1.TickSmaResponse.average', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=732,
  serialized_end=859,
)

_TICKSMAREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKSMAREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_TICKSMAREQUEST.fields_by_name['field'].enum_type = _SMAPRICE
_TICKSMAREQUEST.fields_by_name['period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TICKSMAREQUEST.fields_by_name['offset'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TICKSMAREQUEST.fields_by_name['sampling'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TICKSMARESPONSE.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TICKSMARESPONSE.fields_by_name['average'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
DESCRIPTOR.message_types_by_name['TickSmaRequest'] = _TICKSMAREQUEST
DESCRIPTOR.message_types_by_name['TickSmaResponse'] = _TICKSMARESPONSE
DESCRIPTOR.enum_types_by_name['SmaPrice'] = _SMAPRICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickSmaRequest = _reflection.GeneratedProtocolMessageType('TickSmaRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKSMAREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickSmaRequest)
  })
_sym_db.RegisterMessage(TickSmaRequest)

TickSmaResponse = _reflection.GeneratedProtocolMessageType('TickSmaResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKSMARESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickSmaResponse)
  })
_sym_db.RegisterMessage(TickSmaResponse)



_TICKSMASERVICE = _descriptor.ServiceDescriptor(
  name='TickSmaService',
  full_name='systemathics.apis.services.tick_analytics.v1.TickSmaService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=960,
  serialized_end=1115,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickSma',
    full_name='systemathics.apis.services.tick_analytics.v1.TickSmaService.TickSma',
    index=0,
    containing_service=None,
    input_type=_TICKSMAREQUEST,
    output_type=_TICKSMARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKSMASERVICE)

DESCRIPTOR.services_by_name['TickSmaService'] = _TICKSMASERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_volatility.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/daily_analytics/v1/daily_volatility.proto',
  package='systemathics.apis.services.daily_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nDsystemathics/apis/services/daily_analytics/v1/daily_volatility.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xb2\x01\n\x16\x44\x61ilyVolatilityRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"(\n\x17\x44\x61ilyVolatilityResponse\x12\r\n\x05value\x18\x01 \x01(\x01\x32\xbb\x01\n\x16\x44\x61ilyVolatilityService\x12\xa0\x01\n\x0f\x44\x61ilyVolatility\x12\x45.systemathics.apis.services.daily_analytics.v1.DailyVolatilityRequest\x1a\x46.systemathics.apis.services.daily_analytics.v1.DailyVolatilityResponseb\x06proto3'
  ,
  dependencies=[systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])




_DAILYVOLATILITYREQUEST = _descriptor.Descriptor(
  name='DailyVolatilityRequest',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyVolatilityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.daily_analytics.v1.DailyVolatilityRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.daily_analytics.v1.DailyVolatilityRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.daily_analytics.v1.DailyVolatilityRequest.adjustment', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=401,
)


_DAILYVOLATILITYRESPONSE = _descriptor.Descriptor(
  name='DailyVolatilityResponse',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyVolatilityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.daily_analytics.v1.DailyVolatilityResponse.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=443,
)

_DAILYVOLATILITYREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_DAILYVOLATILITYREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
DESCRIPTOR.message_types_by_name['DailyVolatilityRequest'] = _DAILYVOLATILITYREQUEST
DESCRIPTOR.message_types_by_name['DailyVolatilityResponse'] = _DAILYVOLATILITYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DailyVolatilityRequest = _reflection.GeneratedProtocolMessageType('DailyVolatilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVOLATILITYREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyVolatilityRequest)
  })
_sym_db.RegisterMessage(DailyVolatilityRequest)

DailyVolatilityResponse = _reflection.GeneratedProtocolMessageType('DailyVolatilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVOLATILITYRESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyVolatilityResponse)
  })
_sym_db.RegisterMessage(DailyVolatilityResponse)



_DAILYVOLATILITYSERVICE = _descriptor.ServiceDescriptor(
  name='DailyVolatilityService',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyVolatilityService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=446,
  serialized_end=633,
  methods=[
  _descriptor.MethodDescriptor(
    name='DailyVolatility',
    full_name='systemathics.apis.services.daily_analytics.v1.DailyVolatilityService.DailyVolatility',
    index=0,
    containing_service=None,
    input_type=_DAILYVOLATILITYREQUEST,
    output_type=_DAILYVOLATILITYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAILYVOLATILITYSERVICE)

DESCRIPTOR.services_by_name['DailyVolatilityService'] = _DAILYVOLATILITYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/splits.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/corporate_actions/v1/splits.proto',
  package='systemathics.apis.services.corporate_actions.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<systemathics/apis/services/corporate_actions/v1/splits.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\x95\x01\n\rSplitsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"V\n\x0eSplitsResponse\x12\x44\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.corporate_actions.v1.Split\"P\n\x05Split\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x12\n\nnew_shares\x18\x02 \x01(\x01\x12\x12\n\nold_shares\x18\x03 \x01(\x01\x32\x9b\x01\n\rSplitsService\x12\x89\x01\n\x06Splits\x12>.systemathics.apis.services.corporate_actions.v1.SplitsRequest\x1a?.systemathics.apis.services.corporate_actions.v1.SplitsResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])




_SPLITSREQUEST = _descriptor.Descriptor(
  name='SplitsRequest',
  full_name='systemathics.apis.services.corporate_actions.v1.SplitsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.corporate_actions.v1.SplitsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.corporate_actions.v1.SplitsRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=390,
)


_SPLITSRESPONSE = _descriptor.Descriptor(
  name='SplitsResponse',
  full_name='systemathics.apis.services.corporate_actions.v1.SplitsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.corporate_actions.v1.SplitsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=392,
  serialized_end=478,
)


_SPLIT = _descriptor.Descriptor(
  name='Split',
  full_name='systemathics.apis.services.corporate_actions.v1.Split',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='systemathics.apis.services.corporate_actions.v1.Split.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_shares', full_name='systemathics.apis.services.corporate_actions.v1.Split.new_shares', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_shares', full_name='systemathics.apis.services.corporate_actions.v1.Split.old_shares', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=560,
)

_SPLITSREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_SPLITSREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_SPLITSRESPONSE.fields_by_name['data'].message_type = _SPLIT
_SPLIT.fields_by_name['date'].message_type = google_dot_type_dot_date__pb2._DATE
DESCRIPTOR.message_types_by_name['SplitsRequest'] = _SPLITSREQUEST
DESCRIPTOR.message_types_by_name['SplitsResponse'] = _SPLITSRESPONSE
DESCRIPTOR.message_types_by_name['Split'] = _SPLIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SplitsRequest = _reflection.GeneratedProtocolMessageType('SplitsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPLITSREQUEST,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.splits_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.SplitsRequest)
  })
_sym_db.RegisterMessage(SplitsRequest)

SplitsResponse = _reflection.GeneratedProtocolMessageType('SplitsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SPLITSRESPONSE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.splits_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.SplitsResponse)
  })
_sym_db.RegisterMessage(SplitsResponse)

Split = _reflection.GeneratedProtocolMessageType('Split', (_message.Message,), {
  'DESCRIPTOR' : _SPLIT,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.splits_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.Split)
  })
_sym_db.RegisterMessage(Split)



_SPLITSSERVICE = _descriptor.ServiceDescriptor(
  name='SplitsService',
  full_name='systemathics.apis.services.corporate_actions.v1.SplitsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=563,
  serialized_end=718,
  methods=[
  _descriptor.MethodDescriptor(
    name='Splits',
    full_name='systemathics.apis.services.corporate_actions.v1.SplitsService.Splits',
    index=0,
    containing_service=None,
    input_type=_SPLITSREQUEST,
    output_type=_SPLITSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SPLITSSERVICE)

DESCRIPTOR.services_by_name['SplitsService'] = _SPLITSSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/trade_and_book.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import trade_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__pb2
from systemathics.apis.type.shared.v1 import book_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/trade_and_book.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5systemathics/apis/type/shared/v1/trade_and_book.proto\x12 systemathics.apis.type.shared.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a,systemathics/apis/type/shared/v1/trade.proto\x1a+systemathics/apis/type/shared/v1/book.proto\"\xc2\x01\n\x0cTradeAndBook\x12\x0f\n\x07mapping\x18\x01 \x01(\r\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x05trade\x18\x03 \x01(\x0b\x32\'.systemathics.apis.type.shared.v1.Trade\x12\x39\n\x04\x62ook\x18\x04 \x01(\x0b\x32+.systemathics.apis.type.shared.v1.BookLimitb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2.DESCRIPTOR,])




_TRADEANDBOOK = _descriptor.Descriptor(
  name='TradeAndBook',
  full_name='systemathics.apis.type.shared.v1.TradeAndBook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.type.shared.v1.TradeAndBook.mapping', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.type.shared.v1.TradeAndBook.time_stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade', full_name='systemathics.apis.type.shared.v1.TradeAndBook.trade', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='book', full_name='systemathics.apis.type.shared.v1.TradeAndBook.book', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=461,
)

_TRADEANDBOOK.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRADEANDBOOK.fields_by_name['trade'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__pb2._TRADE
_TRADEANDBOOK.fields_by_name['book'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2._BOOKLIMIT
DESCRIPTOR.message_types_by_name['TradeAndBook'] = _TRADEANDBOOK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TradeAndBook = _reflection.GeneratedProtocolMessageType('TradeAndBook', (_message.Message,), {
  'DESCRIPTOR' : _TRADEANDBOOK,
  '__module__' : 'systemathics.apis.type.shared.v1.trade_and_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.TradeAndBook)
  })
_sym_db.RegisterMessage(TradeAndBook)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/identifier.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/identifier.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1systemathics/apis/type/shared/v1/identifier.proto\x12 systemathics.apis.type.shared.v1\x1a\x1egoogle/protobuf/wrappers.proto\"^\n\nIdentifier\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12.\n\x08provider\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='systemathics.apis.type.shared.v1.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange', full_name='systemathics.apis.type.shared.v1.Identifier.exchange', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='systemathics.apis.type.shared.v1.Identifier.ticker', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='systemathics.apis.type.shared.v1.Identifier.provider', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=213,
)

_IDENTIFIER.fields_by_name['provider'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['Identifier'] = _IDENTIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Identifier = _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFIER,
  '__module__' : 'systemathics.apis.type.shared.v1.identifier_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Identifier)
  })
_sym_db.RegisterMessage(Identifier)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/keys.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/keys.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+systemathics/apis/type/shared/v1/keys.proto\x12 systemathics.apis.type.shared.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"V\n\x03Key\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\r\n\x05value\x18\x02 \x01(\r\"=\n\x04Keys\x12\x35\n\x06values\x18\x01 \x03(\x0b\x32%.systemathics.apis.type.shared.v1.Keyb\x06proto3'
  ,
  dependencies=[systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])




_KEY = _descriptor.Descriptor(
  name='Key',
  full_name='systemathics.apis.type.shared.v1.Key',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.type.shared.v1.Key.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.type.shared.v1.Key.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=218,
)


_KEYS = _descriptor.Descriptor(
  name='Keys',
  full_name='systemathics.apis.type.shared.v1.Keys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='systemathics.apis.type.shared.v1.Keys.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=281,
)

_KEY.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_KEYS.fields_by_name['values'].message_type = _KEY
DESCRIPTOR.message_types_by_name['Key'] = _KEY
DESCRIPTOR.message_types_by_name['Keys'] = _KEYS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Key = _reflection.GeneratedProtocolMessageType('Key', (_message.Message,), {
  'DESCRIPTOR' : _KEY,
  '__module__' : 'systemathics.apis.type.shared.v1.keys_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Key)
  })
_sym_db.RegisterMessage(Key)

Keys = _reflection.GeneratedProtocolMessageType('Keys', (_message.Message,), {
  'DESCRIPTOR' : _KEYS,
  '__module__' : 'systemathics.apis.type.shared.v1.keys_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Keys)
  })
_sym_db.RegisterMessage(Keys)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_bollinger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick_analytics/v1/tick_bollinger.proto',
  package='systemathics.apis.services.tick_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAsystemathics/apis/services/tick_analytics/v1/tick_bollinger.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xc3\x03\n\x14TickBollingerRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12K\n\x05\x66ield\x18\x03 \x01(\x0e\x32<.systemathics.apis.services.tick_analytics.v1.BollingerPrice\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12\x11\n\tdeviation\x18\x05 \x01(\x01\x12)\n\x06period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08sampling\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nadjustment\x18\t \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\n \x03(\t\x12\x0e\n\x06reject\x18\x0b \x03(\t\"\xde\x01\n\x15TickBollingerResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12+\n\x05lower\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x05upper\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x06middle\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue*~\n\x0e\x42ollingerPrice\x12\x1f\n\x1b\x42OLLINGER_PRICE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x42OLLINGER_PRICE_TRADE\x10\x01\x12\x17\n\x13\x42OLLINGER_PRICE_BID\x10\x02\x12\x17\n\x13\x42OLLINGER_PRICE_ASK\x10\x03\x32\xb3\x01\n\x14TickBollingerService\x12\x9a\x01\n\rTickBollinger\x12\x42.systemathics.apis.services.tick_analytics.v1.TickBollingerRequest\x1a\x43.systemathics.apis.services.tick_analytics.v1.TickBollingerResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])

_BOLLINGERPRICE = _descriptor.EnumDescriptor(
  name='BollingerPrice',
  full_name='systemathics.apis.services.tick_analytics.v1.BollingerPrice',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOLLINGER_PRICE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOLLINGER_PRICE_TRADE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOLLINGER_PRICE_BID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOLLINGER_PRICE_ASK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=994,
  serialized_end=1120,
)
_sym_db.RegisterEnumDescriptor(_BOLLINGERPRICE)

BollingerPrice = enum_type_wrapper.EnumTypeWrapper(_BOLLINGERPRICE)
BOLLINGER_PRICE_UNSPECIFIED = 0
BOLLINGER_PRICE_TRADE = 1
BOLLINGER_PRICE_BID = 2
BOLLINGER_PRICE_ASK = 3



_TICKBOLLINGERREQUEST = _descriptor.Descriptor(
  name='TickBollingerRequest',
  full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.field', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.length', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviation', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.deviation', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='period', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.period', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.offset', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.sampling', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.adjustment', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.accept', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reject', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.reject', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=767,
)


_TICKBOLLINGERRESPONSE = _descriptor.Descriptor(
  name='TickBollingerResponse',
  full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lower', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse.lower', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse.upper', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='middle', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse.middle', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=992,
)

_TICKBOLLINGERREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKBOLLINGERREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_TICKBOLLINGERREQUEST.fields_by_name['field'].enum_type = _BOLLINGERPRICE
_TICKBOLLINGERREQUEST.fields_by_name['period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TICKBOLLINGERREQUEST.fields_by_name['offset'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TICKBOLLINGERREQUEST.fields_by_name['sampling'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TICKBOLLINGERRESPONSE.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TICKBOLLINGERRESPONSE.fields_by_name['lower'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_TICKBOLLINGERRESPONSE.fields_by_name['upper'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_TICKBOLLINGERRESPONSE.fields_by_name['middle'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
DESCRIPTOR.message_types_by_name['TickBollingerRequest'] = _TICKBOLLINGERREQUEST
DESCRIPTOR.message_types_by_name['TickBollingerResponse'] = _TICKBOLLINGERRESPONSE
DESCRIPTOR.enum_types_by_name['BollingerPrice'] = _BOLLINGERPRICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickBollingerRequest = _reflection.GeneratedProtocolMessageType('TickBollingerRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOLLINGERREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBollingerRequest)
  })
_sym_db.RegisterMessage(TickBollingerRequest)

TickBollingerResponse = _reflection.GeneratedProtocolMessageType('TickBollingerResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOLLINGERRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBollingerResponse)
  })
_sym_db.RegisterMessage(TickBollingerResponse)



_TICKBOLLINGERSERVICE = _descriptor.ServiceDescriptor(
  name='TickBollingerService',
  full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1123,
  serialized_end=1302,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickBollinger',
    full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerService.TickBollinger',
    index=0,
    containing_service=None,
    input_type=_TICKBOLLINGERREQUEST,
    output_type=_TICKBOLLINGERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKBOLLINGERSERVICE)

DESCRIPTOR.services_by_name['TickBollingerService'] = _TICKBOLLINGERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_raw.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick/v1/tick_raw.proto',
  package='systemathics.apis.services.tick.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1systemathics/apis/services/tick/v1/tick_raw.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xce\x01\n\x0eTickRawRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x36\n\x05level\x18\x03 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Level\"l\n\x0bTickRawItem\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x0e\n\x06source\x18\x03 \x01(\r\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\"U\n\x0fTickRawResponse\x12\x42\n\traw_items\x18\x01 \x03(\x0b\x32/.systemathics.apis.services.tick.v1.TickRawItem\"q\n\x10TickRawResponse2\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x0e\n\x06source\x18\x03 \x01(\r\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x32\x86\x01\n\x0eTickRawService\x12t\n\x07TickRaw\x12\x32.systemathics.apis.services.tick.v1.TickRawRequest\x1a\x33.systemathics.apis.services.tick.v1.TickRawResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])




_TICKRAWREQUEST = _descriptor.Descriptor(
  name='TickRawRequest',
  full_name='systemathics.apis.services.tick.v1.TickRawRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.tick.v1.TickRawRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.tick.v1.TickRawRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='systemathics.apis.services.tick.v1.TickRawRequest.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=478,
)


_TICKRAWITEM = _descriptor.Descriptor(
  name='TickRawItem',
  full_name='systemathics.apis.services.tick.v1.TickRawItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.tick.v1.TickRawItem.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.tick.v1.TickRawItem.type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='systemathics.apis.services.tick.v1.TickRawItem.source', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='systemathics.apis.services.tick.v1.TickRawItem.payload', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=588,
)


_TICKRAWRESPONSE = _descriptor.Descriptor(
  name='TickRawResponse',
  full_name='systemathics.apis.services.tick.v1.TickRawResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_items', full_name='systemathics.apis.services.tick.v1.TickRawResponse.raw_items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=675,
)


_TICKRAWRESPONSE2 = _descriptor.Descriptor(
  name='TickRawResponse2',
  full_name='systemathics.apis.services.tick.v1.TickRawResponse2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.tick.v1.TickRawResponse2.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.tick.v1.TickRawResponse2.type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='systemathics.apis.services.tick.v1.TickRawResponse2.source', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='systemathics.apis.services.tick.v1.TickRawResponse2.payload', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=677,
  serialized_end=790,
)

_TICKRAWREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKRAWREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_TICKRAWREQUEST.fields_by_name['level'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2._LEVEL
_TICKRAWITEM.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TICKRAWRESPONSE.fields_by_name['raw_items'].message_type = _TICKRAWITEM
_TICKRAWRESPONSE2.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['TickRawRequest'] = _TICKRAWREQUEST
DESCRIPTOR.message_types_by_name['TickRawItem'] = _TICKRAWITEM
DESCRIPTOR.message_types_by_name['TickRawResponse'] = _TICKRAWRESPONSE
DESCRIPTOR.message_types_by_name['TickRawResponse2'] = _TICKRAWRESPONSE2
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickRawRequest = _reflection.GeneratedProtocolMessageType('TickRawRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawRequest)
  })
_sym_db.RegisterMessage(TickRawRequest)

TickRawItem = _reflection.GeneratedProtocolMessageType('TickRawItem', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWITEM,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawItem)
  })
_sym_db.RegisterMessage(TickRawItem)

TickRawResponse = _reflection.GeneratedProtocolMessageType('TickRawResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawResponse)
  })
_sym_db.RegisterMessage(TickRawResponse)

TickRawResponse2 = _reflection.GeneratedProtocolMessageType('TickRawResponse2', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWRESPONSE2,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawResponse2)
  })
_sym_db.RegisterMessage(TickRawResponse2)



_TICKRAWSERVICE = _descriptor.ServiceDescriptor(
  name='TickRawService',
  full_name='systemathics.apis.services.tick.v1.TickRawService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=793,
  serialized_end=927,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickRaw',
    full_name='systemathics.apis.services.tick.v1.TickRawService.TickRaw',
    index=0,
    containing_service=None,
    input_type=_TICKRAWREQUEST,
    output_type=_TICKRAWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKRAWSERVICE)

DESCRIPTOR.services_by_name['TickRawService'] = _TICKRAWSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/market_book_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import action_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2
from systemathics.apis.type.shared.v1 import side_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/market_book_updates.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:systemathics/apis/type/shared/v1/market_book_updates.proto\x12 systemathics.apis.type.shared.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a-systemathics/apis/type/shared/v1/action.proto\x1a+systemathics/apis/type/shared/v1/side.proto\"m\n\x11MarketBookUpdates\x12\x13\n\x0bis_snapshot\x18\x01 \x01(\x08\x12\x43\n\x07updates\x18\x02 \x03(\x0b\x32\x32.systemathics.apis.type.shared.v1.MarketBookUpdate\"\xe9\x01\n\x10MarketBookUpdate\x12\x38\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32(.systemathics.apis.type.shared.v1.Action\x12\x34\n\x04side\x18\x02 \x01(\x0e\x32&.systemathics.apis.type.shared.v1.Side\x12\r\n\x05\x64\x65pth\x18\x03 \x01(\r\x12)\n\x04size\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12+\n\x05price\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2.DESCRIPTOR,])




_MARKETBOOKUPDATES = _descriptor.Descriptor(
  name='MarketBookUpdates',
  full_name='systemathics.apis.type.shared.v1.MarketBookUpdates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_snapshot', full_name='systemathics.apis.type.shared.v1.MarketBookUpdates.is_snapshot', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates', full_name='systemathics.apis.type.shared.v1.MarketBookUpdates.updates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=329,
)


_MARKETBOOKUPDATE = _descriptor.Descriptor(
  name='MarketBookUpdate',
  full_name='systemathics.apis.type.shared.v1.MarketBookUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='systemathics.apis.type.shared.v1.MarketBookUpdate.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='systemathics.apis.type.shared.v1.MarketBookUpdate.side', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depth', full_name='systemathics.apis.type.shared.v1.MarketBookUpdate.depth', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='systemathics.apis.type.shared.v1.MarketBookUpdate.size', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='systemathics.apis.type.shared.v1.MarketBookUpdate.price', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=565,
)

_MARKETBOOKUPDATES.fields_by_name['updates'].message_type = _MARKETBOOKUPDATE
_MARKETBOOKUPDATE.fields_by_name['action'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2._ACTION
_MARKETBOOKUPDATE.fields_by_name['side'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2._SIDE
_MARKETBOOKUPDATE.fields_by_name['size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MARKETBOOKUPDATE.fields_by_name['price'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
DESCRIPTOR.message_types_by_name['MarketBookUpdates'] = _MARKETBOOKUPDATES
DESCRIPTOR.message_types_by_name['MarketBookUpdate'] = _MARKETBOOKUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MarketBookUpdates = _reflection.GeneratedProtocolMessageType('MarketBookUpdates', (_message.Message,), {
  'DESCRIPTOR' : _MARKETBOOKUPDATES,
  '__module__' : 'systemathics.apis.type.shared.v1.market_book_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketBookUpdates)
  })
_sym_db.RegisterMessage(MarketBookUpdates)

MarketBookUpdate = _reflection.GeneratedProtocolMessageType('MarketBookUpdate', (_message.Message,), {
  'DESCRIPTOR' : _MARKETBOOKUPDATE,
  '__module__' : 'systemathics.apis.type.shared.v1.market_book_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketBookUpdate)
  })
_sym_db.RegisterMessage(MarketBookUpdate)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/trade.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/trade.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,systemathics/apis/type/shared/v1/trade.proto\x12 systemathics.apis.type.shared.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\x84\x01\n\x05Trade\x12\x0f\n\x07mapping\x18\x01 \x01(\r\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05price\x18\x03 \x01(\x01\x12\x0c\n\x04size\x18\x04 \x01(\x03\x12\x11\n\tcondition\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\tb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])




_TRADE = _descriptor.Descriptor(
  name='Trade',
  full_name='systemathics.apis.type.shared.v1.Trade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.type.shared.v1.Trade.mapping', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.type.shared.v1.Trade.time_stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='systemathics.apis.type.shared.v1.Trade.price', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='systemathics.apis.type.shared.v1.Trade.size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='condition', full_name='systemathics.apis.type.shared.v1.Trade.condition', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='systemathics.apis.type.shared.v1.Trade.id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=299,
)

_TRADE.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Trade'] = _TRADE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Trade = _reflection.GeneratedProtocolMessageType('Trade', (_message.Message,), {
  'DESCRIPTOR' : _TRADE,
  '__module__' : 'systemathics.apis.type.shared.v1.trade_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Trade)
  })
_sym_db.RegisterMessage(Trade)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/side.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/side.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+systemathics/apis/type/shared/v1/side.proto\x12 systemathics.apis.type.shared.v1*8\n\x04Side\x12\x14\n\x10SIDE_UNSPECIFIED\x10\x00\x12\x0c\n\x08SIDE_BID\x10\x01\x12\x0c\n\x08SIDE_ASK\x10\x02\x62\x06proto3'
)

_SIDE = _descriptor.EnumDescriptor(
  name='Side',
  full_name='systemathics.apis.type.shared.v1.Side',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SIDE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIDE_BID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIDE_ASK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=81,
  serialized_end=137,
)
_sym_db.RegisterEnumDescriptor(_SIDE)

Side = enum_type_wrapper.EnumTypeWrapper(_SIDE)
SIDE_UNSPECIFIED = 0
SIDE_BID = 1
SIDE_ASK = 2


DESCRIPTOR.enum_types_by_name['Side'] = _SIDE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/changes.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/corporate_actions/v1/changes.proto',
  package='systemathics.apis.services.corporate_actions.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=systemathics/apis/services/corporate_actions/v1/changes.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\x96\x01\n\x0e\x43hangesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"X\n\x0f\x43hangesResponse\x12\x45\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x37.systemathics.apis.services.corporate_actions.v1.Change\"Q\n\x06\x43hange\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x12\n\nnew_symbol\x18\x02 \x01(\t\x12\x12\n\nold_symbol\x18\x03 \x01(\t2\x9f\x01\n\x0e\x43hangesService\x12\x8c\x01\n\x07\x43hanges\x12?.systemathics.apis.services.corporate_actions.v1.ChangesRequest\x1a@.systemathics.apis.services.corporate_actions.v1.ChangesResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])




_CHANGESREQUEST = _descriptor.Descriptor(
  name='ChangesRequest',
  full_name='systemathics.apis.services.corporate_actions.v1.ChangesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.corporate_actions.v1.ChangesRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.corporate_actions.v1.ChangesRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=392,
)


_CHANGESRESPONSE = _descriptor.Descriptor(
  name='ChangesResponse',
  full_name='systemathics.apis.services.corporate_actions.v1.ChangesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.corporate_actions.v1.ChangesResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=482,
)


_CHANGE = _descriptor.Descriptor(
  name='Change',
  full_name='systemathics.apis.services.corporate_actions.v1.Change',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='systemathics.apis.services.corporate_actions.v1.Change.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_symbol', full_name='systemathics.apis.services.corporate_actions.v1.Change.new_symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_symbol', full_name='systemathics.apis.services.corporate_actions.v1.Change.old_symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=565,
)

_CHANGESREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_CHANGESREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_CHANGESRESPONSE.fields_by_name['data'].message_type = _CHANGE
_CHANGE.fields_by_name['date'].message_type = google_dot_type_dot_date__pb2._DATE
DESCRIPTOR.message_types_by_name['ChangesRequest'] = _CHANGESREQUEST
DESCRIPTOR.message_types_by_name['ChangesResponse'] = _CHANGESRESPONSE
DESCRIPTOR.message_types_by_name['Change'] = _CHANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChangesRequest = _reflection.GeneratedProtocolMessageType('ChangesRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGESREQUEST,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.changes_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.ChangesRequest)
  })
_sym_db.RegisterMessage(ChangesRequest)

ChangesResponse = _reflection.GeneratedProtocolMessageType('ChangesResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGESRESPONSE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.changes_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.ChangesResponse)
  })
_sym_db.RegisterMessage(ChangesResponse)

Change = _reflection.GeneratedProtocolMessageType('Change', (_message.Message,), {
  'DESCRIPTOR' : _CHANGE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.changes_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.Change)
  })
_sym_db.RegisterMessage(Change)



_CHANGESSERVICE = _descriptor.ServiceDescriptor(
  name='ChangesService',
  full_name='systemathics.apis.services.corporate_actions.v1.ChangesService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=568,
  serialized_end=727,
  methods=[
  _descriptor.MethodDescriptor(
    name='Changes',
    full_name='systemathics.apis.services.corporate_actions.v1.ChangesService.Changes',
    index=0,
    containing_service=None,
    input_type=_CHANGESREQUEST,
    output_type=_CHANGESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CHANGESSERVICE)

DESCRIPTOR.services_by_name['ChangesService'] = _CHANGESSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_cma.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/daily_analytics/v1/daily_cma.proto',
  package='systemathics.apis.services.daily_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=systemathics/apis/services/daily_analytics/v1/daily_cma.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x16google/type/date.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xab\x01\n\x0f\x44\x61ilyCmaRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"]\n\x10\x44\x61ilyCmaResponse\x12I\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32;.systemathics.apis.services.daily_analytics.v1.DailyCmaData\"O\n\x0c\x44\x61ilyCmaData\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0f\n\x07\x61verage\x18\x03 \x01(\x01\x32\x9f\x01\n\x0f\x44\x61ilyCmaService\x12\x8b\x01\n\x08\x44\x61ilyCma\x12>.systemathics.apis.services.daily_analytics.v1.DailyCmaRequest\x1a?.systemathics.apis.services.daily_analytics.v1.DailyCmaResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])




_DAILYCMAREQUEST = _descriptor.Descriptor(
  name='DailyCmaRequest',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaRequest.adjustment', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=443,
)


_DAILYCMARESPONSE = _descriptor.Descriptor(
  name='DailyCmaResponse',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=538,
)


_DAILYCMADATA = _descriptor.Descriptor(
  name='DailyCmaData',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaData.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaData.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average', full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaData.average', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=540,
  serialized_end=619,
)

_DAILYCMAREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_DAILYCMAREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_DAILYCMARESPONSE.fields_by_name['data'].message_type = _DAILYCMADATA
_DAILYCMADATA.fields_by_name['date'].message_type = google_dot_type_dot_date__pb2._DATE
DESCRIPTOR.message_types_by_name['DailyCmaRequest'] = _DAILYCMAREQUEST
DESCRIPTOR.message_types_by_name['DailyCmaResponse'] = _DAILYCMARESPONSE
DESCRIPTOR.message_types_by_name['DailyCmaData'] = _DAILYCMADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DailyCmaRequest = _reflection.GeneratedProtocolMessageType('DailyCmaRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYCMAREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyCmaRequest)
  })
_sym_db.RegisterMessage(DailyCmaRequest)

DailyCmaResponse = _reflection.GeneratedProtocolMessageType('DailyCmaResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYCMARESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyCmaResponse)
  })
_sym_db.RegisterMessage(DailyCmaResponse)

DailyCmaData = _reflection.GeneratedProtocolMessageType('DailyCmaData', (_message.Message,), {
  'DESCRIPTOR' : _DAILYCMADATA,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyCmaData)
  })
_sym_db.RegisterMessage(DailyCmaData)



_DAILYCMASERVICE = _descriptor.ServiceDescriptor(
  name='DailyCmaService',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=622,
  serialized_end=781,
  methods=[
  _descriptor.MethodDescriptor(
    name='DailyCma',
    full_name='systemathics.apis.services.daily_analytics.v1.DailyCmaService.DailyCma',
    index=0,
    containing_service=None,
    input_type=_DAILYCMAREQUEST,
    output_type=_DAILYCMARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAILYCMASERVICE)

DESCRIPTOR.services_by_name['DailyCmaService'] = _DAILYCMASERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/mappings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import memo_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_memo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/mappings.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/systemathics/apis/type/shared/v1/mappings.proto\x12 systemathics.apis.type.shared.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/memo.proto\"\x97\x01\n\x07Mapping\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x34\n\x04memo\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.Memo\x12\x14\n\x0c\x65vent_source\x18\x03 \x01(\r\"D\n\x08Mappings\x12\x38\n\x05table\x18\x01 \x03(\x0b\x32).systemathics.apis.type.shared.v1.Mappingb\x06proto3'
  ,
  dependencies=[systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_memo__pb2.DESCRIPTOR,])




_MAPPING = _descriptor.Descriptor(
  name='Mapping',
  full_name='systemathics.apis.type.shared.v1.Mapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.type.shared.v1.Mapping.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memo', full_name='systemathics.apis.type.shared.v1.Mapping.memo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_source', full_name='systemathics.apis.type.shared.v1.Mapping.event_source', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=333,
)


_MAPPINGS = _descriptor.Descriptor(
  name='Mappings',
  full_name='systemathics.apis.type.shared.v1.Mappings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='systemathics.apis.type.shared.v1.Mappings.table', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=403,
)

_MAPPING.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_MAPPING.fields_by_name['memo'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_memo__pb2._MEMO
_MAPPINGS.fields_by_name['table'].message_type = _MAPPING
DESCRIPTOR.message_types_by_name['Mapping'] = _MAPPING
DESCRIPTOR.message_types_by_name['Mappings'] = _MAPPINGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Mapping = _reflection.GeneratedProtocolMessageType('Mapping', (_message.Message,), {
  'DESCRIPTOR' : _MAPPING,
  '__module__' : 'systemathics.apis.type.shared.v1.mappings_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Mapping)
  })
_sym_db.RegisterMessage(Mapping)

Mappings = _reflection.GeneratedProtocolMessageType('Mappings', (_message.Message,), {
  'DESCRIPTOR' : _MAPPINGS,
  '__module__' : 'systemathics.apis.type.shared.v1.mappings_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Mappings)
  })
_sym_db.RegisterMessage(Mappings)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import mappings_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import market_book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2
from systemathics.apis.type.shared.v1 import market_fields_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick/v1/tick_updates.proto',
  package='systemathics.apis.services.tick.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5systemathics/apis/services/tick/v1/tick_updates.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/mappings.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a:systemathics/apis/type/shared/v1/market_book_updates.proto\x1a<systemathics/apis/type/shared/v1/market_fields_updates.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xd3\x01\n\x12TickUpdatesRequest\x12\x41\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x36\n\x05level\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Level\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\xc4\x02\n\x13TickUpdatesResponse\x12\x14\n\x0c\x65vent_source\x18\x01 \x01(\r\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12O\n\x0e\x66ields_updates\x18\x03 \x01(\x0b\x32\x35.systemathics.apis.type.shared.v1.MarketFieldsUpdatesH\x00\x12K\n\x0c\x62ook_updates\x18\x04 \x01(\x0b\x32\x33.systemathics.apis.type.shared.v1.MarketBookUpdatesH\x00\x12>\n\x08mappings\x18\x05 \x01(\x0b\x32*.systemathics.apis.type.shared.v1.MappingsH\x00\x42\t\n\x07payload2\x97\x01\n\x12TickUpdatesService\x12\x80\x01\n\x0bTickUpdates\x12\x36.systemathics.apis.services.tick.v1.TickUpdatesRequest\x1a\x37.systemathics.apis.services.tick.v1.TickUpdatesResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])




_TICKUPDATESREQUEST = _descriptor.Descriptor(
  name='TickUpdatesRequest',
  full_name='systemathics.apis.services.tick.v1.TickUpdatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifiers', full_name='systemathics.apis.services.tick.v1.TickUpdatesRequest.identifiers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='systemathics.apis.services.tick.v1.TickUpdatesRequest.level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.tick.v1.TickUpdatesRequest.constraints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=658,
)


_TICKUPDATESRESPONSE = _descriptor.Descriptor(
  name='TickUpdatesResponse',
  full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_source', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.event_source', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.time_stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields_updates', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.fields_updates', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='book_updates', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.book_updates', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mappings', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.mappings', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=661,
  serialized_end=985,
)

_TICKUPDATESREQUEST.fields_by_name['identifiers'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKUPDATESREQUEST.fields_by_name['level'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2._LEVEL
_TICKUPDATESREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_TICKUPDATESRESPONSE.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TICKUPDATESRESPONSE.fields_by_name['fields_updates'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2._MARKETFIELDSUPDATES
_TICKUPDATESRESPONSE.fields_by_name['book_updates'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2._MARKETBOOKUPDATES
_TICKUPDATESRESPONSE.fields_by_name['mappings'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2._MAPPINGS
_TICKUPDATESRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKUPDATESRESPONSE.fields_by_name['fields_updates'])
_TICKUPDATESRESPONSE.fields_by_name['fields_updates'].containing_oneof = _TICKUPDATESRESPONSE.oneofs_by_name['payload']
_TICKUPDATESRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKUPDATESRESPONSE.fields_by_name['book_updates'])
_TICKUPDATESRESPONSE.fields_by_name['book_updates'].containing_oneof = _TICKUPDATESRESPONSE.oneofs_by_name['payload']
_TICKUPDATESRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKUPDATESRESPONSE.fields_by_name['mappings'])
_TICKUPDATESRESPONSE.fields_by_name['mappings'].containing_oneof = _TICKUPDATESRESPONSE.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['TickUpdatesRequest'] = _TICKUPDATESREQUEST
DESCRIPTOR.message_types_by_name['TickUpdatesResponse'] = _TICKUPDATESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickUpdatesRequest = _reflection.GeneratedProtocolMessageType('TickUpdatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKUPDATESREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickUpdatesRequest)
  })
_sym_db.RegisterMessage(TickUpdatesRequest)

TickUpdatesResponse = _reflection.GeneratedProtocolMessageType('TickUpdatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKUPDATESRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickUpdatesResponse)
  })
_sym_db.RegisterMessage(TickUpdatesResponse)



_TICKUPDATESSERVICE = _descriptor.ServiceDescriptor(
  name='TickUpdatesService',
  full_name='systemathics.apis.services.tick.v1.TickUpdatesService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=988,
  serialized_end=1139,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickUpdates',
    full_name='systemathics.apis.services.tick.v1.TickUpdatesService.TickUpdates',
    index=0,
    containing_service=None,
    input_type=_TICKUPDATESREQUEST,
    output_type=_TICKUPDATESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKUPDATESSERVICE)

DESCRIPTOR.services_by_name['TickUpdatesService'] = _TICKUPDATESSERVICE

# @@protoc_insertion_point(module_scope)
